/*====================================================================================================================
Economic Polarization and Antisocial Behavior: An Experiment

Bigoni, Bortolotti, Nas Ozen

Main analysis do file

NOTES
** Stata 15

** Lables 
Weak players are also called Red playres, and Strong players are also called Blue players
following the names used in the instructions. Similarly, the Safe treatment is coded as seq (from the sequential
nature of the game). The choices are as follows:
down 	--> Exploit
up 		--> Collaborate
right	--> Generous
left	--> Defensive

** External packages
estout


		  
======================================================================================================================*/


*Set cd 
cd "~/Dropbox/Exp_sacrifice/replication_files/data_analysis"

*create folders
capture mkdir graphs
capture mkdir logfiles
capture mkdir tables


*De-comment if you want to save a log file
*capture log close
*log using "logfiles/log_pgg_`c(current_date)'.log", replace


set more off
use data_Main_SB.dta, clear

* ------------------------------------------------------------------------------
* Treatments -- generate treatment related variables and interaction terms
* ------------------------------------------------------------------------------
* generate dummy for the sequential game (Safe treatment in the paper)
gen seq=(order==2)
label define seq 1 "Sequential tr" 0 "Simultaneous tr", modify
label value seq seq

gen noexit=(exit_option==0)
label define noexit 1 "No Exit" 0 "Exit", modify
label value noexit noexit

gen treatmentlist = 2 if seq==1 
replace treatmentlist = 4 if seq==0
replace treatmentlist=treatmentlist-1 if exit_option==1
label define treatmentlist 1 "Seq Exit" 2 "Seq No Exit" 3 "Sim Exit" 4 "Sim No Exit", modify
label value treatmentlist treatmentlist

gen Phase1=tot_period<=5 
gen Phase2=tot_period>5

gen seq_x_tot_period= seq * tot_period
gen exit_option_x_tot_period= exit_option * tot_period
gen seq_x_Phase2 = seq * Phase2

* ------------------------------------------------------------------------------
* Individual characteristics -- generate dummies
* ------------------------------------------------------------------------------
*dummies for foreign and right-wing 
gen foreign_d=country!=1
gen right_d=right>5
* study field and country of origin
tab field, g(fdummy)
label var fdummy1 "Social sciences"
label var fdummy2 "Math sciences"
label var fdummy3 "Engineering-architecture"
label var fdummy4 "Medicine"
label var fdummy5 "Arts-humanities"
label var fdummy6 "Other uni"
label var fdummy7 "Not a uni student"

save data_Main_SB.dta, replace

* ------------------------------------------------------------------------------
* Define macros
* ------------------------------------------------------------------------------
macro define indchar "age i.male i.foreign_d i.right_d i.fdummy1 i.fdummy2 i.fdummy5 wronganswers"
macro define data "data_Main_SB"


*----------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------------------------------------------------------------------------------------------------------
****************************************************************** SECTION 4: RESULTS ***************************************************************
*----------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------------------------------------------------------------------------------------------------------


* ===================================================================================================================================================
* Result 1: Main treatment effect on EXIT
* ===================================================================================================================================================

* ------------------------------------------------------------------------------
* Behavior in Control Treatments
* ------------------------------------------------------------------------------

**** Majority of Weak players choose Collaborate in all ten repetitions of Safe but not Risky: ***

use $data, clear

keep if Color==2

* Nash for Weak
gen Collaborate=choice==2

* Total Collaborate by Subject
bysort session Subject: egen total_collaborate=sum(Collaborate)
tab total_collaborate treatmentlist, col

* Total Collaborate in the first period:
tab Collaborate treatmentlist if tot_period==1, col

* --------------------------- *

*** Defensive by Strong in First Period and Overall: ***

use $data, clear

keep if Color==1
* Nash for Strong
gen Defensive=choice_r==1 if seq==1
replace Defensive=choice==1 if seq==0

* Nash for Weak
gen Collaborate=partnerchoice==2

* Nash_outcome
gen Nash=profit==9

* Exit
gen Exit=profit==0

* Share of profits for Red -- when no exit
gen Share=profit/10 if profit!=0

tab Defensive treatmentlist if tot_period==1, col
tab Defensive treatmentlist, col
* --------------------------- *

* ------------------------------------------------------------------------------
* Table 1: Summary statistics
* ------------------------------------------------------------------------------

*collapse: 1 observation per period and session
collapse Defensive Collaborate Nash Exit Share , by(session tot_period treatmentlist exit_option seq)
tabstat Defensive Collaborate Nash Exit Share, by(treatmentlist)


*** Significance results within text: ***

foreach var of varlist Defensive Collaborate Nash Share{
	xtreg `var' i.seq if exit==0, i(session)
}
* --------------------------- *

* ------------------------------------------------------------------------------
* Figure 5: Actions of Weak players in Exit treatments
* ------------------------------------------------------------------------------

use $data, clear

gen left=choice==3
gen not_right=left+exit
collapse left exit not_right if Color ==2  & inlist(treatmentlist ,1,2,3,4), by(treatmentlist Phase tot_period Period exit_option)
gen tot=1

label define phase 1 "Phase 1" 2 "Phase 2", modify
label values Phase phase

label define tmnt 1 "Safe" 2 "Safe" 3 "Risky" 4 "Risky", modify
label values treatmentlist tmnt

twoway area not_right exit Period if  exit_option, ///
by(treatmentlist Phase, note("")) yscale(r(0 0.4)) ///
fc(gs8*0.30 gs3*0.30) lc(gs8 gs3) xlabel(,grid gmin gmax gs(minor) nogex) ///
ylabel(0(0.1)0.4, format(%3.2f) angle(0) grid gmin gmax gs(minor)) ///
scheme(s1mono) ysize(5) name(gr_exit, replace) legend(order(1 "Exploit" 2 "Exit") row(1)) 
graph export graphs/figure5.png, replace width(1600)



* ------------------------------------------------------------------------------
* Adoption of the Exit option
* ------------------------------------------------------------------------------

*** Shares of Exit in Phases 1, 2 and overall: ***

use $data, clear

*Nash for Reds
gen NashR=choice_r==1 if seq==1
replace NashR=choice==1 if seq==0
replace NashR=. if exit==1
gen NashR_all=choice_r==1 if seq==1 /* does not exclude the cases in which there is exit*/
replace NashR_all=choice==1 if seq==0
*Nash for Blues
gen NashB=choice==2 & Color==2
gen NashB_all=choice==2 & Color==2 /* does not exclude the cases in which there is exit*/
replace NashB=. if exit==1
gen Left=choice==3 & Color==2

collapse NashB* NashR* Left profit exit seq Phase2 seq_x_Phase2 noexit seq_x_tot_period treatmentlist, by(session tot_period Color)

tabstat exit if Color==2 & Phase2==0, by(treatmentlist)
tabstat exit if Color==2 & Phase2==1, by(treatmentlist)
tabstat exit if Color==2, by(treatmentlist)

* --------------------------- *


*** Percent exited at least once: ***

use $data, clear

*Nash for Reds
gen NashR=choice_r==1 if seq==1
replace NashR=choice==1 if seq==0
replace NashR=. if exit==1
gen NashR_all=choice_r==1 if seq==1 /* does not exclude the cases in which there is exit*/
replace NashR_all=choice==1 if seq==0
*Nash for Blues
gen NashB=choice==2 & Color==2
gen NashB_all=choice==2 & Color==2 /* does not exclude the cases in which there is exit*/
replace NashB=. if exit==1
gen Left=choice==3 & Color==2

keep if Color==2
bysort session Subject: egen total_exit=sum(exit)
gen exited=(total_exit>0)
tabstat exited, by(treatmentlist)

* --------------------------- *

* ------------------------------------------------------------------------------
* Table 2: Behavior in Exit Treatments
* ------------------------------------------------------------------------------

use $data, clear

*Nash for Reds
gen NashR=choice_r==1 if seq==1
replace NashR=choice==1 if seq==0
replace NashR=. if exit==1
gen NashR_all=choice_r==1 if seq==1 /* does not exclude the cases in which there is exit*/
replace NashR_all=choice==1 if seq==0
*Nash for Blues
gen NashB=choice==2 & Color==2
gen NashB_all=choice==2 & Color==2 /* does not exclude the cases in which there is exit*/
replace NashB=. if exit==1
gen Left=choice==3 & Color==2

collapse NashB* NashR* Left profit exit seq Phase2 seq_x_Phase2 noexit seq_x_tot_period treatmentlist, by(session tot_period Color)

est clear
noisily xtreg exit seq tot_period seq_x_tot_period if noexit==0 & Color==2, i(session)
est sto reg1
noisily xtreg Left seq tot_period seq_x_tot_period if noexit==0 & Color==2, i(session)
est sto reg2
noisily xtreg NashB_all seq tot_period seq_x_tot_period if noexit==0 & Color==2, i(session)
est sto reg3
noisily xtreg NashR_all seq tot_period seq_x_tot_period if noexit==0 & Color==1, i(session)
est sto reg4

label var seq_x_tot_period "Period $\times$ Safe"
label var seq "Safe tr. (d)"


estout reg* using "./tables/table2.tex", replace stardetach ///
cells(b(star fmt(3)) se(par fmt(3))) substitute( _ "-" -cons "Constant") ///
style(tex) label collabels(,none) margin stats(N r2_o, labels("N.obs." "R-squared (overall)")fmt(0 3)) ///
prehead(\begin{tabular}{p{.2\textwidth}*{5}{r@{}l}} \hline \hline & "\multicolumn{6}{c}{Weak player}  & \multicolumn{2}{c}{Strong player}  \\ & \multicolumn{2}{c}{Exit}& \multicolumn{2}{c}{Exploit} & \multicolumn{2}{c}{Collaborate (NE)} & \multicolumn{2}{c}{Defensive (NE)} \\ &\multicolumn{2}{c}{Model 1} & \multicolumn{2}{c}{Model 2}&\multicolumn{2}{c}{Model 3} & \multicolumn{2}{c}{Model 4} \\") ///
posthead(\hline) prefoot(\hline) postfoot(\hline \multicolumn{11}{p{.7\textwidth}} ///
{\footnotesize{\textbf{Notes:} Models 1 to 4 report results from panel linear regressions with session-level random effects. ///
There is one observation for each period in each session. ///
In Model 1, the dependent variable is the average share of exits by session and period. ///
In Model 2, the dependent variable is the average share of Weak choosing Exploit by session and period. ///
In Model 3, the dependent variable is the average share of Weak choosing Collaborate (Nash) by session and period. ///
In Model 4, the dependent variable is the share of Strong playing Defensive (Nash). ///
For the sequential game we consider only the Collaborate contingency (irrespectively of the actual choice of Weak -- Exploit or Collaborate). ///
Symbols $***$, $**$, and $*$ indicate significance at the 1\%, 5\% and 10\% level, respectively.}}\\ \end{tabular}) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ml(,none) eql(,none)



* ===================================================================================================================================================
* Result 2: Strong Player Behavior
* ===================================================================================================================================================


** Table 2 is above under Result 1 **


*** Share of Defensive for Safe and Risky within the Exit Treatment: ***

use $data, clear

keep if Color==1
* Nash for Strong
gen Defensive=choice_r==1 if seq==1
replace Defensive=choice==1 if seq==0

* Nash for Weak
gen Collaborate=partnerchoice==2

* Nash_outcome
gen Nash=profit==9

* Exit
gen Exit=profit==0

* Share of profits for Strong -- when no exit
gen Share=profit/10 if profit!=0

tab Defensive treatmentlist if tot_period==1, col
tab Defensive treatmentlist, col
* --------------------------- *


*** Consequences of the Introduction of the Exit Option: ***

use $data, clear

*Nash for Reds
gen NashS=choice_r==1 if seq==1
replace NashS=choice==1 if seq==0
replace NashS=. if exit==1
gen NashS_all=choice_r==1 if seq==1 /* does not exclude the cases in which there is exit*/
replace NashS_all=choice==1 if seq==0
*Nash for Blues
gen NashW=choice==2 & Color==2
gen Exploit=choice==3 & Color==2

collapse NashW NashS Exploit profit exit seq Phase2 seq_x_Phase2 noexit seq_x_tot_period treatmentlist, by(session tot_period Color)

tabstat NashW if Color==2, by(noexit)
tabstat NashW if Color==2 & tot_period==1, by(noexit)


* --------------------------- *



* ------------------------------------------------------------------------------
* Table 3: Comparison between the Exit and Control Treatments
* ------------------------------------------------------------------------------

use $data, clear
 
*Nash for Reds
gen NashR=choice_r==1 if seq==1
replace NashR=choice==1 if seq==0
*replace NashR=. if exit==1 /* keep all*/
*Nash for Blues
gen NashB=choice==2 & Color==2
gen Exploit=choice==3 & Color==2
* replace NashB=. if exit==1 /* keep all*/

*collapse: 1 observation per period and session
collapse NashB NashR Exploit profit, by(session tot_period exit_option exit_option_x_tot_period seq seq_x_tot_period Color)


est clear
noisily xtreg Exploit i.exit_option tot_period exit_option_x_tot_period if seq==0 & Color==2, i(session)
est sto reg1
noisily xtreg NashB i.exit_option tot_period exit_option_x_tot_period  if seq==0 & Color==2, i(session)
est sto reg2
noisily xtreg NashR i.exit_option tot_period exit_option_x_tot_period  if seq==0 & Color==1, i(session)
est sto reg3
noisily xtreg Exploit i.exit_option tot_period exit_option_x_tot_period  if seq==1 & Color==2, i(session)
est sto reg4
noisily xtreg NashB i.exit_option tot_period exit_option_x_tot_period  if seq==1 & Color==2, i(session)
est sto reg5
noisily xtreg NashR i.exit_option tot_period exit_option_x_tot_period  if seq==1 & Color==1, i(session)
est sto reg6




label define exit_option 1 "Exit tr. (d)", modify
label values exit_option exit_option

estout reg* using "./tables/table3.tex", replace stardetach ///
cells(b(star fmt(3)) se(par fmt(3))) substitute( _ "-" -cons "Constant") ///
keep(1.exit_option tot_period exit_option_x_tot_period _cons) noomitted ///
style(tex) label collabels(,none) margin stats(N r2_o, labels("N.obs." "R-squared (overall)")fmt(0 3)) ///
prehead(\begin{tabular}{p{.20\textwidth}*{7}{r@{}l}} \hline \hline ///
"&\multicolumn{6}{c}{Risky treatments} & \multicolumn{6}{c}{Safe treatments} \\" ///
"&\multicolumn{2}{c}{Exploit} & \multicolumn{2}{c}{Collaborate (NE) } & \multicolumn{2}{c}{Defensive (NE)}" ///
"& \multicolumn{2}{c}{Exploit} & \multicolumn{2}{c}{Collaborate (NE) } & \multicolumn{2}{c}{Defensive (NE)}\\ " ///
"&\multicolumn{2}{c}{Model 1} & \multicolumn{2}{c}{Model 2}&\multicolumn{2}{c}{Model 3} & \multicolumn{2}{c}{Model 4} & \multicolumn{2}{c}{Model 5} & \multicolumn{2}{c}{Model 6} \\") ///
posthead(\hline) prefoot(\hline) postfoot(\hline \multicolumn{15}{p{.85\textwidth}} ///
{\footnotesize{\textbf{Notes:} Models 1 to 6 report results from panel linear regressions with session-level random effects. ///
There is one observation for each period in each session. ///
In Models 1 and 4, the dependent variable is the average share of Weak players choosing Exploit by session and period. ///
In Models 2 and 5, the dependent variable is the average share of Weak players playing Collaborate (Nash). ///
In Models 3 and 6, the dependent variable is the average share of Strong players playing Defensive (Nash). ///
For the sequential game we consider only the Collaborate contingency (irrespectively of the actual choice of Weak -- Exploit or Collaborate). ///
Symbols $***$, $**$, and $*$ indicate significance at the 1\%, 5\% and 10\% level, respectively.}}\\ \end{tabular}) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ml(,none) eql(,none)





* ===================================================================================================================================================
* Result 3: Individual history
* ===================================================================================================================================================
use $data, clear
keep if exit_option==1
keep if Color==2

gen Period_x_seq=Period*seq
gen Phase2_x_seq=Phase2*seq

gen partnerdown=(partnerchoice==0 & exit==0)
bysort session Subject (tot_period): gen partnerdown_periodsbj=sum(partnerdown)
bysort session Subject (tot_period): gen l_partnerdown_periodsbj=partnerdown_periodsbj[_n-1]
gen l_partnerdown_periodsbj_x_seq= l_partnerdown_periodsbj*seq

macro define indchar "age i.male i.foreign_d i.right_d i.fdummy1 i.fdummy2 i.fdummy5 wronganswers"

egen sbj=group(Subject session)
xtset sbj tot_period

gen seen_nash=(l_partnerdown_periodsbj==0)
replace seen_nash=1 if Period==1 & Phase==1
gen seennash_x_seq=seen_nash*seq
label var seen_nash "Never observed Generous"
label var seennash_x_seq "Never observed Generous * Seq."

egen exit_ph2=sum(exit) if Phase==2, by(Subject session )
egen temp=mean(exit_ph2 ), by(Subject session )
replace exit_ph2 =temp if Phase1
drop temp
replace exit_ph2 =1 if exit_ph2 >0


* ------------------------------------------------------------------------------
* Figure 6: Frequency of Exit for Weak Players Who Never Observed Generous
* ------------------------------------------------------------------------------


gen count=1
collapse exit (sum) count, by(seq Phase Period seen_nash)

label define phase 1 "Phase 1" 2 "Phase 2", modify
label values Phase phase

twoway ///
connected exit Period if !seq & seen_nash, lp("-#") lw(0.6) ms(d) color(black) mlabel(count) mlabp(12)|| ///
connected exit Period if  seq & seen_nash, lp(l) lw(0.6) ms(o) color(black) mlabel(count) mlabp(12) ///
legend(order(1 "Risky" 2 "Safe") pos(11) ring(0) col(2)) ytitle("Frequency of Exit") by(Phase, note("Note: Exit by weak players only.")) ///
xtitle("") scheme(s1mono) ylabel(0(.2)0.65,format(%4.2f) grid gmin gmax angle(0) gs(minor)) xlabel(,grid gs(minor))
graph export graphs/figure6.png, replace width(1600)

* --------------------------- *


* ------------------------------------------------------------------------------
* Table 4: Individual-level History and the Exit Option
* ------------------------------------------------------------------------------

use $data, clear

keep if exit_option==1

gen Period_x_seq=Period*seq
label var Period_x_seq "Period $\times$ Safe"
label define seq 1 "Safe tr. (d)", modify

egen num=sum(profit), by(session matched_set Phase Color)
egen tot=sum(profit), by(session matched_set Phase)
gen  den=tot-num
gen  temp=num/den
bysort session Subject Period (Phase): gen ratio_profit_ph1=temp[_n-1]
gen ratio_profit_ph1_x_seq=seq * ratio_profit_ph1
label var ratio_profit_ph1 "Payoff ratio (ph.1)"
label var ratio_profit_ph1_x_seq "Payoff ratio (ph.1) $\times$ Safe"
drop num tot den temp

keep if Color==2

gen partnerdown=(partnerchoice==0 & exit==0)
bysort session Subject (tot_period): gen partnerdown_periodsbj=sum(partnerdown)
bysort session Subject (tot_period): gen l_partnerdown_periodsbj=partnerdown_periodsbj[_n-1]
gen l_partnerdown_periodsbj_x_seq= l_partnerdown_periodsbj*seq
label var l_partnerdown_periodsbj "Observed Generous "
label var l_partnerdown_periodsbj_x_seq "Obs. Generous $\times$ Safe"

bysort session Subject (tot_period): gen exit_periodsbj=sum(exit)
bysort session Subject (tot_period): gen l_exit_periodsbj=exit_periodsbj[_n-1]
gen l_exit_periodsbj_x_seq =l_exit_periodsbj * seq
label var l_exit_periodsbj "N. previous exit"
label var l_exit_periodsbj_x_seq "N. previous exit $\times$ Safe"

egen exit_phasesbj=sum(exit), by(Subject session Phase)
egen exit_matchinggroup=sum(exit), by(matched_set session Phase)
gen  exit_otherweak=exit_matchinggroup-exit_phasesbj
bysort session Subject Period (Phase): gen exit_otherweak_ph1=exit_otherweak[_n-1]
gen exit_otherweak_ph1_x_seq = exit_otherweak_ph1 * seq
label var exit_otherweak_ph1 "Exit by other Weak in Ph.1"
label var exit_otherweak_ph1_x_seq "Exit by other Weak in Ph.1 $\times$ Safe"

macro define indchar "age i.male i.foreign_d i.right_d i.fdummy1 i.fdummy2 i.fdummy5 wronganswers"

egen sbj=group(Subject session)
xtset sbj tot_period

est clear

set more off

* Phase 1:
noi xtprobit exit i.seq Period Period_x_seq l_partnerdown_periodsbj* $indchar if !Phase2, vce(cluster session)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg1
estadd scalar bic=bic

* Phase 2:
noi xtprobit exit i.seq Period Period_x_seq l_partnerdown_periodsbj* $indchar if  Phase2, vce(cluster session)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg2
estadd scalar bic=bic

noi xtprobit exit i.seq Period Period_x_seq ratio_profit_ph1* $indchar if  Phase2, vce(cluster session)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg4
estadd scalar bic=bic


noi xtprobit exit i.seq Period Period_x_seq exit_otherweak_ph1* $indchar if Phase2, vce(cluster session)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg5
estadd scalar bic=bic


noi xtprobit exit i.seq Period Period_x_seq l_partnerdown_periodsbj* ratio_profit_ph1* exit_otherweak_ph1* $indchar if Phase2, vce(cluster session)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg6
estadd scalar bic=bic


estout reg* using "./tables/table4.tex", replace stardetach ///
cells(b(star fmt(3)) se(par fmt(3))) substitute( _ "-" -cons "Constant") ///
indicate(Individual characteristics = age 1.male 1.foreign_d 1.right_d 1.fdummy1 1.fdummy2 1.fdummy5 wronganswers) ///
keep(Period 1.seq Period_x_seq l_partnerdown_periodsbj* ratio_profit_ph1* exit_otherweak_ph1*) noomitted ///
style(tex) label collabels(,none) margin stats(N bic, labels("N.obs." "BIC") fmt(0 3)) ///
prehead(\begin{tabular}{p{.25\textwidth}*{6}{r@{}l}} \hline \hline & ///
"\multicolumn{8}{c}{Exit (Yes=1 and No=0)} \\ & \multicolumn{8}{c}{Only Weak players} \\" /// 
"& \multicolumn{2}{c}{Phase 1 only} & \multicolumn{8}{c}{Phase 2 only} \\" /// 
"&\multicolumn{2}{c}{Model 1} & \multicolumn{2}{c}{Model 2}& \multicolumn{2}{c}{Model 3}& \multicolumn{2}{c}{Model 4}& \multicolumn{2}{c}{Model 5} \\") ///
posthead(\hline) prefoot(\hline) postfoot(\hline \multicolumn{13}{p{.8\textwidth}} ///
{\footnotesize{\textbf{Notes:} Models 1 to 5 report the marginal effects from panel probit regressions on exit choices of Weak players, with random effects at the subject level. ///
The dependent variable takes value 1 if Weak chooses Exit and 0 otherwise. ///
Model 1 includes only Phase 1, Models 2 to 5 include Phase 2 only. ///
Controls for indivudual characteristics include age and the number of mistakes made in the control questions, ///
and a set of dummies for: male, political orientation (indicating self-reported right-wing political views), ///
non-German subjects, field of study (social sciences, hard sciences, and humanities). ///
Standard errors robust for clustering at the session level (in parentheses). ///
Symbols $***$, $**$, and $*$ indicate significance at the 1\%, 5\% and 10\% level, respectively.}}\\ \end{tabular}) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ml(,none) eql(,none)


*----------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------------------------------------------------------------------------------------------------------
***************************************************** SECTION 5: THE DRIVERS OF EXIT: EXPECTATIONS **************************************************
*----------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------------------------------------------------------------------------------------------------------


* ------------------------------------------------------------------------------
* Figure 6: Expectations about Strong and Weak Player Actions
* ------------------------------------------------------------------------------

use data_Beliefs, clear

* Panel a (Strong players): 
gen guess2_seq=guess2-0.1
gen guess2_sim=guess2+0.1
twoway (histogram guess2_seq if sequential, discrete fcolor(gs2%60) lcolor(gs2) lwidth(vthin) gap(50) barwidth(0.95)) ///
       (histogram guess2_sim if !sequential, discrete fcolor(gs12%70) lcolor(gs2) lwidth(thin) gap(50) barwidth(0.95) ///
        scheme(s1mono) legend(order(1 "Safe" 2 "Risky")) ylabel(0(0.05)0.35,grid gmin gmax gs(minor) angle(0) format(%3.2f)) ///
        xlabel(0(1)10,grid gmin gmax angle(0) format(%1.0f) gs(minor))ytitle("") xtitle("Number of DEFENSIVE (Nash) out of 10") )
graph export ./graphs/figure7a.png, replace width(1600)

* Panel b (Weak players): 
gen guess1_seq=guess1-0.1
gen guess1_sim=guess1+0.1
twoway (histogram guess1_seq if sequential, discrete fcolor(gs2%60) lcolor(gs2) lwidth(vthin) gap(50) barwidth(0.95)) ///
       (histogram guess1_sim if !sequential, discrete fcolor(gs12%70) lcolor(gs2) lwidth(thin) gap(50) barwidth(0.95) ///
        scheme(s1mono) legend(order(1 "Safe" 2 "Risky")) ylabel(0(0.05)0.35,grid gmin gmax gs(minor) angle(0) format(%3.2f)) ///
        xlabel(0(1)10,grid gmin gmax angle(0) format(%1.0f) gs(minor))ytitle("") xtitle("Number of COLLABORATE (Nash) out of 10"))
graph export ./graphs/figure7b.png, replace width(1600)

* --------------------------- *

*** Results quoted in text: ***

tabstat guess1, by(sequential)
ranksum guess1, by(sequential)

tabstat guess2, by(sequential)
ranksum guess2, by(sequential)

* --------------------------- *


*----------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------------------------------------------------------------------------------------------------------
************************************************************ APPENDIX A: TABLES AND FIGURES *********************************************************
*----------------------------------------------------------------------------------------------------------------------------------------------------
*----------------------------------------------------------------------------------------------------------------------------------------------------

* ------------------------------------------------------------------------------
* Figure A1: Actions of Weak players in Control treatments
* ------------------------------------------------------------------------------
* ------------------------------------------------------------------------------

use $data, clear

gen left=choice==3
collapse left exit if Color ==2  & inlist(treatmentlist ,1,2,3,4), by(treatmentlist Phase tot_period Period exit_option)

label define phase 1 "Phase 1" 2 "Phase 2", modify
label values Phase phase

label define tmnt 1 "Safe" 2 "Safe" 3 "Risky" 4 "Risky", modify
label values treatmentlist tmnt

twoway area left Period if  !exit_option, ///
by(treatmentlist Phase, note("")) yscale(r(0 0.4)) ///
fc(gs8*0.30 gs3*0.30) lc(gs8 gs3) xlabel(,grid gmin gmax gs(minor) nogex) ///
ylabel(0(0.1)0.4, format(%3.2f) angle(0) grid gmin gmax gs(minor))  ytitle("Percentage of Exploit") ///
scheme(s1mono) ysize(5) name(gr_noexit, replace) legend(order(1 "Exploit") row(1)) 
graph export ./graphs/figureA1.png, replace width(800)

* --------------------------- *


* ------------------------------------------------------------------------------
* Figure A2: Actions of Strong players in all treatments
* ------------------------------------------------------------------------------

use $data, clear
gen down=choice==0 if !seq
replace down=choice_r==0 if seq
gen not_up=down+exit
collapse down exit not_up if Color ==1  & inlist(treatmentlist ,1,2,3,4), by(treatmentlist Phase tot_period Period exit_option)
gen tot=1

label define phase 1 "Phase 1" 2 "Phase 2", modify
label values Phase phase

label define tmnt 1 "Safe-Exit" 2 "Safe-NoExit" 3 "Risky-Exit" 4 "Risky-NoExit", modify
label values treatmentlist tmnt

twoway area not_up exit Period, ///
by(treatmentlist Phase, note("") col(2) scale(0.8)) yscale(r(0 0.4)) ///
fc(gs12*.30 navy*.70) lc(gs12 navy*.70) xlabel(,grid gmin gmax gs(minor) nogex) ///
ylabel(0(0.1)0.4, format(%2.1f) angle(0) grid gmin gmax gs(minor)) ///
scheme(s1mono) ysize(12) xsize(10) legend(order(1 "Generous" 2 "Exit") row(1))
graph export ./graphs/figureA2.png, replace width(1600)

* --------------------------- *

* ------------------------------------------------------------------------------
* Table A1: Individual Histories and Exit Behavior
* ------------------------------------------------------------------------------

use $data, clear
keep if exit_option==1
keep if Color==2

gen Period_x_seq=Period*seq
gen Phase2_x_seq=Phase2*seq

gen partnerdown=(partnerchoice==0 & exit==0)
bysort session Subject (tot_period): gen partnerdown_periodsbj=sum(partnerdown)
bysort session Subject (tot_period): gen l_partnerdown_periodsbj=partnerdown_periodsbj[_n-1]
gen l_partnerdown_periodsbj_x_seq= l_partnerdown_periodsbj*seq

macro define indchar "age i.male i.foreign_d i.right_d i.fdummy1 i.fdummy2 i.fdummy5 wronganswers"

egen sbj=group(Subject session)
xtset sbj tot_period

gen seen_nash=(l_partnerdown_periodsbj==0)
replace seen_nash=1 if Period==1 & Phase==1
gen seennash_x_seq=seen_nash*seq
label var seen_nash "Never observed Generous"
label var seennash_x_seq "Never observed Generous * Seq."

egen exit_ph2=sum(exit) if Phase==2, by(Subject session )
egen temp=mean(exit_ph2 ), by(Subject session )
replace exit_ph2 =temp if Phase1
drop temp
replace exit_ph2 =1 if exit_ph2 >0



* Treatment effect interacted with Period -- on those who have never seen a deviation from Nash
est clear

set more off

* Phase 1:
noi xtprobit exit c.Period i.seq c.Period_x_seq $indchar if !Phase2 & seen_nash==1, vce(cluster session)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg1
estadd scalar bic=bic


* Phase 2:
noi xtprobit exit c.Period i.seq c.Period_x_seq $indchar if Phase2 & seen_nash==1, vce(cluster session)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg2
estadd scalar bic=bic


* Total:
noi xtprobit exit c.Period i.Phase2 i.seq i.Phase2_x_seq c.Period_x_seq $indchar if seen_nash==1, vce(cluster session)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg3
estadd scalar bic=bic


* Treatment effect interacted with Period -- on those who have seen at least one deviation from Nash

* Phase 1:
* (need to drop the dummy for male since female never exit here)
noi xtprobit exit c.Period i.seq c.Period_x_seq age i.foreign_d i.right_d i.fdummy1 i.fdummy2 i.fdummy5 wronganswers if !Phase2 & seen_nash==0, vce(cluster session) intpoints(8)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg4
estadd scalar bic=bic


* Phase 2:
noi xtprobit exit c.Period i.seq c.Period_x_seq $indchar if Phase2 & seen_nash==0, vce(cluster session)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg5
estadd scalar bic=bic


* Total:
noi xtprobit exit c.Period i.Phase2 i.seq i.Phase2_x_seq c.Period_x_seq $indchar if seen_nash==0, vce(cluster session)
estat ic
matrix list r(S)
matrix S=r(S)
scalar bic=S[1,6]
margins, dydx(*) post
est sto reg6
estadd scalar bic=bic


label var Period_x_seq "Period $\times$ Safe"
label var Phase2_x_seq "Phase 2 $\times$ Safe"


estout reg? using "./tables/tableA1.tex", replace stardetach ///
cells(b(star fmt(3)) se(par fmt(3))) substitute( _ "-" -cons "Constant") ///
indicate(Individual characteristics = age 1.male 1.foreign_d 1.right_d 1.fdummy1 1.fdummy2 1.fdummy5 wronganswers) ///
keep(Period 1.seq Period_x_seq 1.Phase2 1.Phase2_x_seq) noomitted ///
style(tex) label collabels(,none) margin stats(N bic, labels("N.obs." "BIC")fmt(0 3)) ///
prehead(\begin{tabular}{p{.25\textwidth}*{7}{r@{}l}} \hline \hline & ///
"\multicolumn{10}{c}{Exit option (Only Weak players, Yes=1 and No=0)} \\ & \multicolumn{6}{c}{Never observed Generous} & \multicolumn{6}{c}{Observed Generous at least once}  \\" /// 
"& \multicolumn{2}{c}{Phase 1 only} & \multicolumn{2}{c}{Phase 2 only} & \multicolumn{2}{c}{All phases} & \multicolumn{2}{c}{Phase 1 only} & \multicolumn{2}{c}{Phase 2 only} & \multicolumn{2}{c}{All phases} \\" /// 
"&\multicolumn{2}{c}{Model 1} & \multicolumn{2}{c}{Model 2}& \multicolumn{2}{c}{Model 3}& \multicolumn{2}{c}{Model 4} & \multicolumn{2}{c}{Model 5} & \multicolumn{2}{c}{Model 6} \\") ///
posthead(\hline) prefoot(\hline) postfoot(\hline \multicolumn{13}{p{1\textwidth}} ///
{\footnotesize{\textbf{Notes:} Models 1 to 6 report the marginal effects from probit regressions on exit choices of Weak players, with random effects at the subject level. ///
The dependent variable takes value 1 if Weak chooses Exit and 0 otherwise. ///
Models 1 and 4 include Phase 1 only, Models 2 and 5 include Phase 2 only, Models 3 and 6 include both phases. ///
In all models except Model 4, controls for indivudual characteristics include age and the number of mistakes made in the control questions, ///
and a set of dummies for: male, political orientation (indicating self-reported right-wing political views), ///
non-German subjects, field of study (social sciences, hard sciences, and humanities). ///
In Model 4, controls for indivudual characteristics include age and the number of mistakes made in the control questions, ///
and a set of dummies for: political orientation (indicating self-reported right-wing political views), ///
non-German subjects, field of study (social sciences, hard sciences, and humanities). ///
The difference in Model 4 is because only male subjects exited in Phase 1. ///
Standard errors robust for clustering at the session level (in parentheses). ///
Symbols $***$, $**$, and $*$ indicate significance at the 1\%, 5\% and 10\% level, respectively.}}\\ \end{tabular}) ///
starlevels(* 0.10 ** 0.05 *** 0.01) ml(,none) eql(,none)

* --------------------------- *

* ------------------------------------------------------------------------------
* Figure A3: Frequency of Exit for Weak Players Who Saw At Least One Generous Choice
* ------------------------------------------------------------------------------

use $data, clear
keep if exit_option==1
keep if Color==2

gen Period_x_seq=Period*seq
gen Phase2_x_seq=Phase2*seq

gen partnerdown=(partnerchoice==0 & exit==0)
bysort session Subject (tot_period): gen partnerdown_periodsbj=sum(partnerdown)
bysort session Subject (tot_period): gen l_partnerdown_periodsbj=partnerdown_periodsbj[_n-1]
gen l_partnerdown_periodsbj_x_seq= l_partnerdown_periodsbj*seq


gen seen_nash=(l_partnerdown_periodsbj==0)
replace seen_nash=1 if Period==1 & Phase==1
gen seennash_x_seq=seen_nash*seq
label var seen_nash "Never observed Generous"
label var seennash_x_seq "Never observed Generous * Seq."

egen exit_ph2=sum(exit) if Phase==2, by(Subject session )
egen temp=mean(exit_ph2 ), by(Subject session )
replace exit_ph2 =temp if Phase1
drop temp
replace exit_ph2 =1 if exit_ph2 >0

est clear
set more off

gen count=1
collapse exit (sum) count, by(seq Phase Period seen_nash)

label define phase 1 "Phase 1" 2 "Phase 2", modify
label values Phase phase


twoway ///
connected exit Period if !seq & !seen_nash, lp("-#") lw(0.6) ms(d) color(black) mlabel(count) mlabp(12)|| ///
connected exit Period if  seq & !seen_nash, lp(l) lw(0.6) ms(o) color(black) mlabel(count) mlabp(6) ///
legend(order(1 "Risky" 2 "Safe") pos(11) ring(0) col(2)) ytitle("Frequency of Exit") by(Phase, note("Note: Exit by weak players only.")) ///
xtitle("") scheme(s1mono) ylabel(0(.05)0.20,format(%4.2f) grid gmin gmax angle(0) gs(minor)) xlabel(,grid gs(minor)) yscale(r(-0.02 0.2))
graph export ./graphs/figureA3.png, replace width(1600)


* --------------------------- *

